@@ -9,16 +9,13 @@
         x <- as.matrix(x)
     d <- ncol(x)
     n <- nrow(x)
-#    nterms <- .Fortran("mkpoly", as.integer(m), as.integer(d), 
-#        nterms = as.integer(0), PACKAGE = "fields")$nterms
-#    print(nterms)
-    nterms<- choose((m + d -1),d)
+    nterms <- choose((m + d - 1), d)
     temp <- .Fortran("dmaket", m = as.integer(m), n = as.integer(n), 
         dim = as.integer(d), des = as.double(x), lddes = as.integer(n), 
         npoly = as.integer(nterms), tmatrix = as.double(rep(0, 
             n * (nterms))), ldt = as.integer(n), wptr = as.integer(rep(0, 
             d * m)), info = as.integer(0), ptab = as.integer(rep(0, 
-            nterms * d)), ldptab = as.integer(nterms), PACKAGE = "fields")
+            nterms * d)), ldptab = as.integer(nterms))
     temp2 <- matrix(temp$tmatrix, nrow = n)
     attr(temp2, "ptab") <- matrix(temp$ptab, nrow = nterms, ncol = d)
     temp2
