@@ -1,53 +1,15 @@
 # fields, Tools for spatial data
-# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
+# Copyright 2004-2013, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-"plot.qsreg" <- function(x, pch = "*", main = NA, 
-    ...) {
-    out <- x
-    old.par <- par("mfrow", "oma")
-    on.exit(par(old.par))
-    set.panel(2, 2, relax = TRUE)
-    plot(out$x, out$y, xlab = "X", ylab = "y", pch = pch)
-    orderx <- order(out$x)
-    temp <- out$fitted.values[, c(out$ind.cv, out$ind.cv.ps)]
-    matlines(out$x[orderx], temp[orderx, ], lty = 1, col = c(1, 
-        2))
-    ##
-    # residual plot
-    #
-    matplot(out$x, qsreg.psi(out$residuals[, c(out$ind.cv, out$ind.cv.ps)], 
-        out$alpha, out$sc), col = c(1, 2), pch = "o", ylab = "Pseudo residuals", 
-        xlab = "X")
-    yline(0)
-    if (nrow(out$cv.grid) > 1) {
-        ind <- out$cv.grid[, 3] < 1e+19
-        out$cv.grid <- out$cv.grid[ind, ]
-        matplot(out$cv.grid[, 2], cbind(out$cv.grid[, 3], out$cv.grid[, 
-            6]), xlab = "Effective number of parameters", ylab = "Log CV Rho function ", 
-            log = "y", type = "l", col = c(1, 2))
-        xline(out$cv.grid[out$ind.cv, 2], col = 1)
-        xline(out$cv.grid[out$ind.cv.ps, 2], col = 2)
-        title(" CV curves", cex = 0.5)
-    }
-    bplot(qsreg.psi(out$residuals[, c(out$ind.cv, out$ind.cv.ps)], 
-        out$alpha, out$sc), names = c("CV", "CV pseudo"))
-    yline(0, col = 2)
-    if (is.na(main)) 
-        mtext(deparse(out$call), cex = 1.3, outer = TRUE, line = -2)
-    else mtext(main, cex = 1.3, outer = TRUE, line = -2)
-}
-"predict.qsreg" <- function(object, x, derivative = 0, 
-    model = object$ind.cv.ps, ...) {
-    if (missing(x)) 
-        x <- object$x
-    c(splint(object$predicted$x, object$predicted$y[, model], 
-        x, derivative = derivative))
-}
+
 "qsreg" <- function(x, y, lam = NA, maxit = 50, maxit.cv = 10, 
     tol = 1e-07, offset = 0, sc = sqrt(var(y)) * 1e-05, alpha = 0.5, 
     wt = rep(1, length(x)), cost = 1, nstep.cv = 80, hmin = NA, 
     hmax = NA, trmin = 2 * 1.05, trmax = 0.95 * length(unique(x))) {
+    
+    # see the function QTps for a different computational implementation
+    # and a code that works for more than 1-d.
     out <- list()
     class(out) <- c("qsreg")
     N <- length(y)
@@ -126,7 +88,7 @@
         #
         # call the robust spline but set the cutoff for the huber weight so big
         # it is essentially a LS spline this helps to match the lambda for robust spline
-        # with a LS one.
+        # with a lambda for the LS one.
         #
         b <- .Fortran("rcss", h = as.double(h[k]), npoint = as.integer(N), 
             x = as.double(x), y = as.double(y.pseudo), wt = as.double(wt), 
@@ -136,7 +98,6 @@
             job = as.integer(c(3, 3, 0)), ideriv = as.integer(0), 
             din = as.double(c(cost, offset, maxit, tol, sqrt(var(y)) * 
                 10, alpha)), dout = as.double(rep(0, 4)), ierr = as.integer(0))
-
         #
         # CV residuals based on pseudo-data)
         # Use the linear approximation  Y_k - f.cv_k = (Y_k- f_k)/( 1- A_kk)
@@ -192,7 +153,27 @@
         dout = as.double(rep(0, 4)), ierr = as.integer(0))$dout
     return(temp)
 }
-"qsreg.psi" <- function(r, alpha = 0.5, C = 1) {
+
+
+qsreg.psi <- function(r, alpha = 0.5, C = 1) {
+    
+    temp <- ifelse(r < 0, 2 * (1 - alpha) * r/C, 2 * alpha * 
+        r/C)
+    temp <- ifelse(temp > 2 * alpha, 2 * alpha, temp)
+    temp <- ifelse(temp < -2 * (1 - alpha), -2 * (1 - alpha), 
+        temp)
+    temp
+}
+
+qsreg.rho <- function(r, alpha = 0.5, C = 1) {
+    temp <- ifelse(r < 0, ((1 - alpha) * r^2)/C, (alpha * r^2)/C)
+    temp <- ifelse(r > C, 2 * alpha * r - alpha * C, temp)
+    temp <- ifelse(r < -C, -2 * (1 - alpha) * r - (1 - alpha) * 
+        C, temp)
+    temp
+}
+# next two functions included for just checking with new versions
+"qsreg.psi.OLD" <- function(r, alpha = 0.5, C = 1) {
     temp <- rep(NA, length(r))
     r <- r/C
     temp <- r
@@ -206,7 +187,7 @@
     temp[ind] <- 2 * (1 - alpha) * r[ind]
     temp
 }
-"qsreg.rho" <- function(r, alpha = 0.5, C = 1) {
+"qsreg.rho.OLD" <- function(r, alpha = 0.5, C = 1) {
     temp <- rep(NA, length(r))
     ind <- r > C
     temp[ind] <- 2 * alpha * r[ind] - alpha * C
@@ -218,3 +199,106 @@
     temp[ind] <- ((1 - alpha) * r[ind]^2)/C
     temp
 }
+# fields, Tools for spatial data
+# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
+# University Corporation for Atmospheric Research
+# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+"qsreg.trace" <- function(x, y, lam, maxit = 50, maxit.cv = 10, 
+    tol = 1e-04, offset = 0, sc = sqrt(var(y)) * 1e-07, alpha = 0.5, 
+    wt = rep(1, length(x)), cost = 1) {
+    N <- length(y)
+    if (length(x) != length(y)) 
+        stop(" X and Y do not match")
+    h <- log(lam)
+    temp <- .Fortran("rcss", h = as.double(log(lam)), npoint = as.integer(N), 
+        x = as.double(x), y = as.double(y), wt = as.double(wt), 
+        sy = as.double(rep(0, N)), trace = as.double(0), diag = as.double(rep(0, 
+            N)), cv = as.double(0), ngrid = as.integer(0), xg = as.double(0), 
+        yg = as.double(0), job = as.integer(c(3, 0, 0)), ideriv = as.integer(0), 
+        din = as.double(c(cost, offset, maxit, tol, sc, alpha)), 
+        dout = as.double(rep(0, 4)), ierr = as.integer(0))$dout
+    return(temp[3])
+}
+# fields, Tools for spatial data
+# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
+# University Corporation for Atmospheric Research
+# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+"summary.qsreg" <- function(object, ...) {
+    x <- object
+    digits <- 4
+    c1 <- "Number of Observations:"
+    c2 <- (x$N)
+    c1 <- c(c1, "Effective degrees of freedom:")
+    c2 <- c(c2, format(round(x$trace[x$ind.cv.ps], 1)))
+    c1 <- c(c1, "Residual degrees of freedom:")
+    c2 <- c(c2, format(round(x$N - x$trace[x$ind.cv.ps], 1)))
+    c1 <- c(c1, "Log10(lambda)")
+    c2 <- c(c2, format(round(log10(x$cv.grid[x$ind.cv.ps, 1]), 
+        2)))
+    sum <- cbind(c1, c2)
+    dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
+    cat("Call:\n")
+    dput(x$call)
+    print(sum, quote = FALSE)
+    invisible(x)
+}
+"plot.qsreg" <- function(x, pch = "*", main = NA, 
+    ...) {
+    out <- x
+    old.par <- par("mfrow", "oma")
+    on.exit(par(old.par))
+    set.panel(2, 2, relax = TRUE)
+    plot(out$x, out$y, xlab = "X", ylab = "y", pch = pch)
+    orderx <- order(out$x)
+    temp <- out$fitted.values[, c(out$ind.cv, out$ind.cv.ps)]
+    matlines(out$x[orderx], temp[orderx, ], lty = 1, col = c(1, 
+        2))
+    ##
+    # residual plot
+    #
+    matplot(out$x, qsreg.psi(out$residuals[, c(out$ind.cv, out$ind.cv.ps)], 
+        out$alpha, out$sc), col = c(1, 2), pch = "o", ylab = "Pseudo residuals", 
+        xlab = "X")
+    yline(0)
+    if (nrow(out$cv.grid) > 1) {
+        ind <- out$cv.grid[, 3] < 1e+19
+        out$cv.grid <- out$cv.grid[ind, ]
+        matplot(out$cv.grid[, 2], cbind(out$cv.grid[, 3], out$cv.grid[, 
+            6]), xlab = "Effective number of parameters", ylab = "Log CV Rho function ", 
+            log = "y", type = "l", col = c(1, 2))
+        xline(out$cv.grid[out$ind.cv, 2], col = 1)
+        xline(out$cv.grid[out$ind.cv.ps, 2], col = 2)
+        title(" CV curves", cex = 0.5)
+    }
+    bplot(qsreg.psi(out$residuals[, c(out$ind.cv, out$ind.cv.ps)], 
+        out$alpha, out$sc), names = c("CV", "CV pseudo"))
+    yline(0, col = 2)
+    if (is.na(main)) 
+        mtext(deparse(out$call), cex = 1.3, outer = TRUE, line = -2)
+    else mtext(main, cex = 1.3, outer = TRUE, line = -2)
+}
+"predict.qsreg" <- function(object, x, derivative = 0, 
+    model = object$ind.cv.ps, ...) {
+    if (missing(x)) 
+        x <- object$x
+    c(splint(object$predicted$x, object$predicted$y[, model], 
+        x, derivative = derivative))
+}
+"print.qsreg" <- function(x, ...) {
+    digits <- 4
+    c1 <- "Number of Observations:"
+    c2 <- (x$N)
+    c1 <- c(c1, "Effective degrees of freedom:")
+    c2 <- c(c2, format(round(x$trace[x$ind.cv.ps], 1)))
+    c1 <- c(c1, "Residual degrees of freedom:")
+    c2 <- c(c2, format(round(x$N - x$trace[x$ind.cv.ps], 1)))
+    c1 <- c(c1, "Log10(lambda) ")
+    lambda <- x$cv.grid[, 1]
+    c2 <- c(c2, format(round(log10(lambda[x$ind.cv.ps]), 2)))
+    sum <- cbind(c1, c2)
+    dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
+    cat("Call:\n")
+    dput(x$call)
+    print(sum, quote = FALSE)
+    invisible(x)
+}
